@@ -1,6 +1,11 @@
 /**************************************************************************
- *  Kchmviewer - a CHM file viewer with broad language support            *
- *  Copyright (C) 2004-2010 George Yunaev, kchmviewer@ulduzsoft.com       *
+ *  Kchmviewer - a portable CHM file viewer with the best support for     *
+ *  the international languages                                           *
+ *                                                                        *
+ *  Copyright (C) 2004-2012 George Yunaev, kchmviewer@ulduzsoft.com       *
+ *                                                                        *
+ *  Please read http://www.kchmviewer.net/reportbugs.html if you want     *
+ *  to report a bug. It lists things I need to fix it!                    *
  *                                                                        *
  *  This program is free software: you can redistribute it and/or modify  *
  *  it under the terms of the GNU General Public License as published by  *
@@ -1036,8 +1041,16 @@ bool LCHMFileImpl::parseFileAndFillArray( const QString & file, QVector< LCHMPar
 		else if ( tagword == "/object" && in_object ) 
 		{
 			// a topic entry closed. Add a tree item
-			if ( !entry.name.isEmpty() )
+			if ( entry.name.isEmpty() && entry.urls.isEmpty() )
 			{
+				qWarning ("LCHMFileImpl::ParseAndFillTopicsTree: <object> tag is parsed, but both name and url are empty.");
+			}
+			else
+			{
+				// If the name is empty, use the URL as name
+				if ( entry.name.isEmpty() )
+					entry.name = entry.urls[0];
+
 				if ( !root_indent_offset_set )
 				{
 					root_indent_offset_set = true;
@@ -1055,13 +1068,6 @@ bool LCHMFileImpl::parseFileAndFillArray( const QString & file, QVector< LCHMPar
 				entry.indent = real_indent;
 				data->push_back( entry );
 			}
-			else
-			{
-				if ( !entry.urls.isEmpty() )
-					qWarning ("LCHMFileImpl::ParseAndFillTopicsTree: <object> tag with url \"%s\" is parsed, but name is empty.", qPrintable( entry.urls[0] ));
-				else
-					qWarning ("LCHMFileImpl::ParseAndFillTopicsTree: <object> tag is parsed, but both name and url are empty.");	
-			}
 
 			entry.name = QString::null;
 			entry.urls.clear();
