@@ -1,6 +1,11 @@
 /**************************************************************************
- *  Kchmviewer - a CHM file viewer with broad language support            *
- *  Copyright (C) 2004-2010 George Yunaev, kchmviewer@ulduzsoft.com       *
+ *  Kchmviewer - a portable CHM file viewer with the best support for     *
+ *  the international languages                                           *
+ *                                                                        *
+ *  Copyright (C) 2004-2012 George Yunaev, kchmviewer@ulduzsoft.com       *
+ *                                                                        *
+ *  Please read http://www.kchmviewer.net/reportbugs.html if you want     *
+ *  to report a bug. It lists things I need to fix it!                    *
  *                                                                        *
  *  This program is free software: you can redistribute it and/or modify  *
  *  it under the terms of the GNU General Public License as published by  *
@@ -53,6 +58,7 @@ int main( int argc, char ** argv )
 	options.add( "search <query>", ki18n("'--search <query>' specifies the search query to search, and activate the first entry if found") );
 	options.add( "sindex <word>", ki18n("'--sindex <word>' specifies the word to find in index, and activate if found") );
 	options.add( "stoc <word>", ki18n("'--stoc <word(s)>' specifies the word(s) to find in TOC, and activate if found. Wildcards allowed.") );
+	options.add( "url <word>", ki18n("'--url <relative url>' specifies the URL to activate if found.") );
 
 	KAboutData aboutdata ( "kchmviewer",
 				QByteArray(),
@@ -70,7 +76,7 @@ int main( int argc, char ** argv )
 
 	KApplication app;
 #else
-        KchmviewerApp app( argc, argv );
+	KchmviewerApp app( argc, argv );
 
 	app.addLibraryPath ( "qt-plugins" );
 #endif
@@ -97,10 +103,10 @@ int main( int argc, char ** argv )
 			qWarning( "Cannot register service %s on session bus. Going without D-BUS support.", SERVICE_NAME );
 	}
 	else
-                qWarning( "Cannot connect to the D-BUS session bus. Going without D-BUS support." );
+		qWarning( "Cannot connect to the D-BUS session bus. Going without D-BUS support." );
 #endif
 
-        mainWindow = new MainWindow();
+	mainWindow = new MainWindow();
 	mainWindow->show();
 	
 	app.connect( &app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()) );
