@@ -1,6 +1,11 @@
 /**************************************************************************
- *  Kchmviewer - a CHM file viewer with broad language support            *
- *  Copyright (C) 2004-2010 George Yunaev, kchmviewer@ulduzsoft.com       *
+ *  Kchmviewer - a portable CHM file viewer with the best support for     *
+ *  the international languages                                           *
+ *                                                                        *
+ *  Copyright (C) 2004-2012 George Yunaev, kchmviewer@ulduzsoft.com       *
+ *                                                                        *
+ *  Please read http://www.kchmviewer.net/reportbugs.html if you want     *
+ *  to report a bug. It lists things I need to fix it!                    *
  *                                                                        *
  *  This program is free software: you can redistribute it and/or modify  *
  *  it under the terms of the GNU General Public License as published by  *
@@ -99,8 +104,13 @@ MainWindow::MainWindow()
 
 	qApp->setWindowIcon( QPixmap(":/images/kchmviewer.png") );
 
-	m_recentFiles = new RecentFiles( menu_File, file_exit_action, pConfig->m_numOfRecentFiles );
-	connect( m_recentFiles, SIGNAL(openRecentFile(QString)), this, SLOT(actionOpenRecentFile(QString)) );
+	if ( pConfig->m_numOfRecentFiles > 0 )
+	{
+		m_recentFiles = new RecentFiles( menu_File, file_exit_action, pConfig->m_numOfRecentFiles );
+		connect( m_recentFiles, SIGNAL(openRecentFile(QString)), this, SLOT(actionOpenRecentFile(QString)) );
+	}
+	else
+		m_recentFiles = 0;
 
 	// Basically disable everything
 	updateActions();
@@ -225,7 +235,9 @@ bool MainWindow::loadFile ( const QString &loadFileName, bool call_open_page )
 				openPage( m_chmFile->homeUrl() );
 		}
 
-		m_recentFiles->setCurrentFile( m_chmFilename );
+		if ( m_recentFiles )
+			m_recentFiles->setCurrentFile( m_chmFilename );
+
 		return true;
 	}
 	else
@@ -270,25 +282,22 @@ void MainWindow::refreshCurrentBrowser( )
 }
 
 
+void MainWindow::activateUrl( const QUrl & link )
+{
+	activateLink( link.toString() );
+}
 
-void MainWindow::activateLink ( const QString & link, bool& follow_link )
+void MainWindow::activateLink ( const QString & link )
 {
 	if ( link.isEmpty() )
 		return;
 	
 	if ( gKeyEventFilter.isShiftPressed() )
-	{
 		openPage( link, OPF_NEW_TAB | OPF_CONTENT_TREE );
-		follow_link = false;
-	}
 	else if ( gKeyEventFilter.isCtrlPressed() )
-	{
 		openPage( link, OPF_NEW_TAB | OPF_BACKGROUND );
-		follow_link = false;
-	}
 	else
-		// If the openPage failed, we do not need to follow the link.
-		follow_link = openPage( link, OPF_CONTENT_TREE | OPF_ADD2HISTORY );
+		openPage( link, OPF_CONTENT_TREE | OPF_ADD2HISTORY );
 }
 
 
@@ -329,7 +338,7 @@ bool MainWindow::openPage( const QString & srcurl, unsigned int flags )
 	}
 		
 	// Filter the URLs which do not need to be opened at all by Qt version
-	if ( LCHMUrlFactory::isJavascriptURL (url) )
+	if ( LCHMUrlFactory::isJavascriptURL(url)  )
 	{
 		QMessageBox::information( this, 
 			i18n( "%1 - JavsScript link clicked") . arg(QCoreApplication::applicationName()),
@@ -363,6 +372,7 @@ bool MainWindow::openPage( const QString & srcurl, unsigned int flags )
 	}
 	
 	ViewWindow * vwnd = currentBrowser();
+
 	if ( flags & OPF_NEW_TAB )
 		vwnd = m_viewWindowMgr->addNewTab( !(flags & OPF_BACKGROUND) );
 	
@@ -388,7 +398,7 @@ void MainWindow::firstShow()
 {
 	if ( !parseCmdLineArgs( ) )
 	{
-		if ( pConfig->m_startupMode == Config::STARTUP_LOAD_LAST_FILE && !m_recentFiles->latestFile().isEmpty() )
+		if ( m_recentFiles && pConfig->m_startupMode == Config::STARTUP_LOAD_LAST_FILE && !m_recentFiles->latestFile().isEmpty() )
 		{
 			loadFile( m_recentFiles->latestFile() );
 			return;
@@ -474,7 +484,7 @@ void MainWindow::closeEvent ( QCloseEvent * e )
 bool MainWindow::parseCmdLineArgs( )
 {
 	QString filename = QString::null, search_query = QString::null;
-	QString search_index = QString::null, search_bookmark = QString::null, search_toc = QString::null;
+	QString search_index = QString::null, open_url = QString::null, search_toc = QString::null;
 	bool do_autotest = false;
 
 #if defined (USE_KDE)
@@ -486,6 +496,7 @@ bool MainWindow::parseCmdLineArgs( )
 	search_query = args->getOption ("search");
 	search_index = args->getOption ("sindex");
 	search_toc = args->getOption ("stoc");
+	open_url = args->getOption ("url");
 	
 	if ( args->count() > 0 )
 		filename = args->arg(0);
@@ -499,7 +510,8 @@ bool MainWindow::parseCmdLineArgs( )
 					"    The following options supported:\n"
 					"  --search <query> specifies the search query to search, and activate the first entry if found\n"
 					"  --sindex <word>  specifies the word to find in index, and activate if found\n"
-					"  --stoc <word(s)> specifies the word(s) to find in TOC, and activate if found. Wildcards allowed\n",
+					"  --stoc <word(s)> specifies the word(s) to find in TOC, and activate if found. Wildcards allowed\n"
+					"  --url <word>     specifies the URL to activate if found.",
 	 				qApp->argv()[0] );
 			
 			exit (1);
@@ -512,6 +524,8 @@ bool MainWindow::parseCmdLineArgs( )
 			search_index = qApp->argv()[++i];
 		else if ( !strcmp (qApp->argv()[i], "--stoc") )
 			search_toc = qApp->argv()[++i];
+		else if ( !strcmp (qApp->argv()[i], "--url") )
+			open_url = qApp->argv()[++i];
 		else
 			filename = QString::fromLocal8Bit( qApp->argv()[i] );
 	}
@@ -522,21 +536,25 @@ bool MainWindow::parseCmdLineArgs( )
 		if ( !loadFile( filename ) )
 			return true; // skip the latest checks, but do not exit from the program
 
-		if ( !search_index.isEmpty() )
+		if ( !open_url.isEmpty() )
+		{
+			QStringList event_args;
+			event_args.push_back( open_url );
+			qApp->postEvent( this, new UserEvent( "openPage", event_args ) );
+		}
+		else if ( !search_index.isEmpty() )
 		{
 			QStringList event_args;
 			event_args.push_back( search_index );
 			qApp->postEvent( this, new UserEvent( "findInIndex", event_args ) );
 		}
-		
-		if ( !search_query.isEmpty() )	
+		else if ( !search_query.isEmpty() )
 		{
 			QStringList event_args;
 			event_args.push_back( search_query );
 			qApp->postEvent( this, new UserEvent( "searchQuery", event_args ) );
 		}
-		
-		if ( !search_toc.isEmpty() )	
+		else if ( !search_toc.isEmpty() )
 		{
 			QStringList event_args;
 			event_args.push_back( search_toc );
@@ -839,12 +857,12 @@ void MainWindow::actionExtractCHM()
 
 void MainWindow::actionFontSizeIncrease()
 {
-	currentBrowser()->addZoomFactor( 1 );
+	currentBrowser()->zoomIncrease();
 }
 
 void MainWindow::actionFontSizeDecrease()
 {
-	currentBrowser()->addZoomFactor( -1 );
+	currentBrowser()->zoomDecrease();
 }
 
 void MainWindow::actionViewHTMLsource()
